@@ -19,7 +19,7 @@
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
   02111-1307, USA.
 
-  Copyright  2002-2004 Jan-ke Larsson
+  Copyright (C) 2002-2004 Jan-ke Larsson
 
 ************************************************************************/
 
@@ -227,7 +227,7 @@ uint32_t CommandLength(unsigned char* command)
   length = dvi_commandlength[*command];
   switch (*command)  {
   case XXX1: case XXX2: case XXX3: case XXX4: 
-    length += UNumRead((char*)command + 1,length - 1);
+    length += UNumRead(command + 1,length - 1);
     break;
   case FNT_DEF1: case FNT_DEF2: case FNT_DEF3: case FNT_DEF4: 
     length += *(command + length - 1) + *(command + length - 2);
