@@ -19,7 +19,7 @@
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
   02111-1307, USA.
 
-  Copyright  2002-2004 Jan-ke Larsson
+  Copyright (C) 2002-2004 Jan-ke Larsson
 
 ************************************************************************/
 
@@ -41,8 +41,20 @@
 #define MAKETEXPK "mktexpk"
 
 #ifdef HAVE_INTTYPES_H
-#include <inttypes.h>
-#else
+#  include <inttypes.h>
+#  ifndef HAVE_INT64_T
+/* Sometimes we want to use gcc -ansi -pedantic as a portability test
+ * The typedef of int64_t is not in the system header file in that
+ * case. Then, define int64_t as "long long" here. "long long" is
+ * non-ansi, but is present in most modern compilers */
+#    ifdef HAVE_LONG_LONG
+typedef long long                int64_t;
+typedef unsigned long long      uint64_t;
+#    else
+#      error Your system lacks 64-bit integer types
+#    endif
+#  endif
+#else /* HAVE_INTTYPES_H */
 typedef signed char               int8_t;
 typedef unsigned char            uint8_t;
 typedef short                    int16_t;
@@ -51,7 +63,8 @@ typedef int                      int32_t;
 typedef unsigned int            uint32_t;
 typedef long long                int64_t;
 typedef unsigned long long      uint64_t;
-#endif
+#endif /* HAVE_INTTYPES_H */
+
 
 #ifndef INT32_MIN
 #define INT32_MIN   (-2147483647-1)
@@ -59,11 +72,26 @@ typedef unsigned long long      uint64_t;
 #ifndef INT32_MAX
 #define INT32_MAX   (2147483647)
 #endif
-              
+
+#ifdef HAVE_STDBOOL_H
+#include <stdbool.h>
+#endif
+
 #include <gd.h>
 
 #ifdef HAVE_LIBKPATHSEA
-#include <kpathsea/kpathsea.h>
+# include <kpathsea/kpathsea.h>
+/* boolean is an enum type from kpathsea/types.h loaded in
+   kpathsea/kpathsea.h, use it as fallback */
+# ifndef __bool_true_false_are_defined
+#  define bool boolean
+# endif
+#else
+/* This is really insufficient, currently no path searches will work
+   without kpathsea anyway */
+typedef int bool;
+# define true (bool) 1
+# define false (bool) 0
 #endif
 
 #ifdef HAVE_FT2
@@ -77,14 +105,6 @@ typedef unsigned long long      uint64_t;
 #include <t1lib.h>
 #endif
 
-#ifdef HAVE_STDBOOL_H
-#include <stdbool.h>
-#else
-typedef  int     bool;
-#define  true      (bool) 1
-#define  false     (bool) 0
-#endif
-
 #ifndef HAVE_VPRINTF
 # ifdef HAVE_DOPRNT
 #  define   vfprintf(stream, message, args)  _doprnt(message, args, stream)
@@ -121,6 +141,9 @@ typedef int32_t dviunits;
 /* integer round to the nearest number, not towards zero */
 #define PIXROUND(num,den) ((num)>0 ? ((num)+(den)/2)/(den) : -(((den)/2-(num))/(den)))
 
+#if HAVE_ALLOCA_H
+# include <alloca.h>
+#endif
 #define TEMPSTR(s,a) { char* tmp=a; \
                if (tmp!=NULL) {\
                  s=alloca(strlen(tmp)+1);strcpy(s,tmp);free(tmp);\
@@ -193,7 +216,7 @@ struct filemmap {
 #else  /* MIKTEX */
   int fd;
 #endif	/* MIKTEX */
-  void* mmap;
+  char* mmap;
   size_t size;
 };
 
@@ -363,6 +386,7 @@ void      EndVFMacro(void);
 /**************************************************/
 void handlepapersize(char*,int32_t*,int32_t*);
 
+void stringrgb(char* colorstring,int *r,int *g,int *b);
 void background(char *);
 void initcolor(void);
 void popcolor(void);
@@ -412,6 +436,7 @@ EXTERN struct internal_state {
 #define MODE_STRICT                  (1<<16)
 #define NO_GHOSTSCRIPT               (1<<17)
 #define NO_GSSAFER                   (1<<18)
+#define BG_TRANSPARENT               (1<<19)
 EXTERN uint32_t flags INIT(BE_NONQUIET | USE_FREETYPE | USE_LIBT1);
 
 #ifdef DEBUG
@@ -510,6 +535,10 @@ EXTERN  int y_pwidth INIT(0);
 /* The transparent border preview-latex desires */
 EXTERN  int borderwidth INIT(0);
 
+/* fallback color for transparent background */
+EXTERN bool userbordercolor INIT(FALSE); /* if true, use user-supplied color */
+EXTERN struct dvi_color bordercolor;
+
 
 EXTERN gdImagePtr page_imagep INIT(NULL);
 EXTERN int32_t shrinkfactor INIT(4);
