@@ -19,7 +19,7 @@
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
   02111-1307, USA.
 
-  Copyright  2002-2004 Jan-ke Larsson
+  Copyright (C) 2002-2004 Jan-ke Larsson
 
 ************************************************************************/
 
@@ -29,7 +29,7 @@
 #else
 #define basename xbasename
 #endif
-#include <fcntl.h> // open/close
+#include <fcntl.h> /* open/close */
 #include <sys/mman.h>
 #include <sys/stat.h>
 
@@ -244,14 +244,14 @@ bool DecodeArgs(int argc, char ** argv)
 	  if (*p == 0 && argv[i+1])
 	    p = argv[++i] ;
 	  if (strncmp(p,"Transparent",11) == 0 ) 
-	    borderwidth=-1;
+	    flags |= BG_TRANSPARENT;
 	  else
 	    background(p);
-	  if (borderwidth>=0) 
-	    Message(PARSE_STDIN,"Background: rgb %d,%d,%d\n",
+	  if (flags & BG_TRANSPARENT) 
+	    Message(PARSE_STDIN,"Transp. background (fallback rgb %d,%d,%d)\n",
 		    cstack[0].red,cstack[0].green,cstack[0].blue);
 	  else 
-	    Message(PARSE_STDIN,"Transp. background (fallback rgb %d,%d,%d)\n",
+	    Message(PARSE_STDIN,"Background: rgb %d,%d,%d\n",
 		    cstack[0].red,cstack[0].green,cstack[0].blue);
 	  break;
 	} else if (strcmp(p, "dpi")==0) {
@@ -264,11 +264,26 @@ bool DecodeArgs(int argc, char ** argv)
 	  Message(PARSE_STDIN,"Bdpi: %d\n",user_bdpi);
 	  break;
 	} else if ( *p == 'd' ) { /* -bd border width */
+	  int tmpi;
+	  char* tmps;
 	  p++;
 	  if (*p == 0 && argv[i+1])
 	    p = argv[++i] ;
-	  borderwidth = atoi(p);
-	  Message(PARSE_STDIN,"Transp. border: %d dots\n",borderwidth);
+	  tmpi = strtol(p, &tmps, 10);
+	  if (p<tmps) {
+	    borderwidth=tmpi;
+	    Message(PARSE_STDIN,"Transp. border: %d dots\n",borderwidth);
+	  }
+	  if (*tmps) {
+	    stringrgb(tmps, &bordercolor.red, &bordercolor.green, &bordercolor.blue);
+	    userbordercolor=TRUE;
+	    if (borderwidth==0) {
+	      borderwidth=1;
+	      Message(PARSE_STDIN,"Transp. border: %d dots\n",borderwidth);
+	    }
+	    Message(PARSE_STDIN,"Transp. border: rgb %d,%d,%d\n",
+		    bordercolor.red, bordercolor.green, bordercolor.blue);
+	  }
 	  break;
 	} 
 	goto DEFAULT;
@@ -521,7 +536,8 @@ named COPYING and dvipng.c.");
     fprintf(stdout,"  -            Interactive query of options\n");
     fprintf(stdout,"\nThese do not correspond to dvips options:\n");
     fprintf(stdout,"  -bd #        Transparent border width in dots\n");
-    fprintf(stdout,"  -bdpi #      Set the base (Metafont) resolution\n");
+    fprintf(stdout,"  -bd s        Transparent border fallback color (TeX-style color)\n");
+    fprintf(stdout,"  --bdpi #     Set the base (Metafont) resolution\n");
     fprintf(stdout,"  -bg s        Background color (TeX-style color)\n");
     fprintf(stdout,"  --depth*     Output the image depth on stdout\n");
     fprintf(stdout,"  --dvinum*    Use TeX page numbers in output filenames\n");
@@ -530,13 +546,18 @@ named COPYING and dvipng.c.");
 #ifdef HAVE_FT2
     fprintf(stdout,"  --freetype*  FreeType font rendering (default on)\n");
 #endif
+    fprintf(stdout,"  --gamma #    Control color interpolation\n");
 #ifdef HAVE_GDIMAGEGIF
     fprintf(stdout,"  --gif        Output GIF images (dvigif default)\n");
 #endif
     fprintf(stdout,"  --height*    Output the image height on stdout\n");
+    fprintf(stdout,"  --noghostscript*  Don't use ghostscript for PostScript specials\n");
+    fprintf(stdout,"  --nogssafer* Don't use -dSAFER in ghostscript calls\n");
+    fprintf(stdout,"  --picky      When a warning occurs, don't output image\n");
 #ifdef HAVE_GDIMAGEGIF
     fprintf(stdout,"  --png        Output PNG images (dvipng default)\n");
 #endif
+    fprintf(stdout,"  --strict     When a warning occurs, exit\n");
 #ifdef HAVE_LIBT1
     fprintf(stdout,"  --t1lib*     T1lib font rendering (default on)\n");
 #endif
@@ -694,7 +715,7 @@ bool MmapFile (char *filename,struct filemmap *fmmap)
   fstat(fmmap->fd,&stat);
   fmmap->size=stat.st_size;
   fmmap->mmap = mmap(NULL,fmmap->size, PROT_READ, MAP_SHARED,fmmap->fd,0);
-  if (fmmap->mmap == (unsigned char *)-1) {
+  if (fmmap->mmap == (char*)-1) {
     Warning("cannot mmap file <%s>",filename);
     fmmap->mmap=NULL;
     close(fmmap->fd);
